==> movim_0.14.1.orig.tar.gz: movim-0.14.1/README.md <==
Movim - Decentralized social platform
=====================================

Movim is a decentralized social platform, written in PHP and HTML5 and based on the XMPP standard protocol.

![movim logo](https://movim.eu/img/chatroom.png)

Installation
------------
Please refer to the installation instructions that are available on the GitHub Wiki: https://github.com/movim/movim/wiki

Support Us
----------
You can help Movim by:
* Doing a one time donation using Paypal: [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=8QHPJDAQXT9UC)
* Helping us covering our monthly costs on our official Patreon page: [![Donate](https://img.shields.io/badge/Patreon-Become%20a%20Patron-orange.svg)](https://www.patreon.com/movim)
* …or on Liberapay [![Donate](https://img.shields.io/liberapay/receives/movim.svg)](https://liberapay.com/movim/donate)


You can also support us on:
* Flattr: https://flattr.com/thing/568092/Movim
* Bountysource: https://www.bountysource.com/teams/movim

Links
-----
* Movim official website: https://movim.eu/
* Twitter: https://twitter.com/MovimNetwork
* XMPP Chatroom: movim@conference.movim.eu

### Pods
You can also use Movim on our official Pods:

* https://fr.movim.eu/ server hosted in France
* https://nl.movim.eu/ server hosted in The Netherlands
* https://de.movim.eu/ server hosted in Germany

Translations
------------
Help us translate Movim on https://www.transifex.com/projects/p/movim/.

License
-------
Movim is released under the terms of the AGPLv3 license. See COPYING for more details.

==> movim_0.17.1.orig.tar.gz: movim-0.17.1/README.md <==
Movim - Decentralized social platform
=====================================

Movim is a decentralized social platform, written in PHP and HTML5 and based on the XMPP standard protocol.

![movim logo](https://movim.eu/img/home.png)

Installation
------------
Please refer to the installation instructions that are available on the GitHub Wiki: https://github.com/movim/movim/wiki

Movim is also available as a [Docker image](https://github.com/movim/movim_docker) or as a [Debian package](https://packages.debian.org/movim).

Support Us
----------
You can help Movim by:
* Doing a one time donation using Paypal: [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=8QHPJDAQXT9UC)
* Helping us covering our monthly costs on our official Patreon page: [![Donate](https://img.shields.io/badge/Patreon-Become%20a%20Patron-orange.svg)](https://www.patreon.com/movim)
* …or on Liberapay [![Donate](https://img.shields.io/liberapay/receives/movim.svg)](https://liberapay.com/movim/donate)

You can also support us on:
* Flattr: https://flattr.com/thing/568092/Movim
* Bountysource: https://www.bountysource.com/teams/movim

Links
-----
* Movim official website: https://movim.eu/
* Twitter: https://twitter.com/MovimNetwork
* XMPP Chatroom: movim@conference.movim.eu

### Pods
You can also use Movim on our official Pods:

* https://nl.movim.eu/ server hosted in The Netherlands
* https://jp.mov.im/ server hosted in Japan
* https://de.movim.eu server hosted in Germany

Translations
------------
Help us translate Movim on https://www.transifex.com/projects/p/movim/.

License
-------
Movim is released under the terms of the AGPLv3 license. See COPYING for more details.
